==> nextcloud-app-news-1%3A25.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/vi.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Bài chưa đọc",
    "Download" : "Tải về",
    "Close" : "Đóng",
    "Web address" : "Địa chỉ Web",
    "No folder" : "Không có thư mục nào",
    "Folder name" : "Tên thư mục",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Feed exists already!" : "Nguồn đã tồn tại",
    "New folder" : "Tạo thư mục",
    "Folder exists already!" : "Thư mục đã tồn tại!",
    "Credentials" : "Giấy chứng nhận",
    "Subscribe" : "Theo dõi",
    "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
    "Move" : "Dịch chuyển",
    "Share" : "Chia sẻ",
    "Mark read" : "Đánh dấu là đã đọc",
    "All articles" : "Mọi bài viết",
    "Starred" : "Starred",
    "Settings" : "Cài đặt",
    "Keyboard shortcuts" : "Phím tắt",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Rename Feed" : "Đổi tên nguồn dữ liệu",
    "Newest first" : "Mới trước",
    "Oldest first" : "Cũ trước",
    "by" : "bởi",
    "from" : "từ",
    "Open website" : "Mở trang web",
    "Keyboard shortcut" : "Phím tắt",
    "Action" : "Hành động",
    "right" : "phải",
    "left" : "trái",
    "Refresh" : "Làm mới",
    "Shift" : "Shift",
    "Description" : "Mô tả",
    "Folder" : "Thư mục",
    "Go back" : "Quay lại",
    "Create" : "Tạo",
    "Dismiss" : "Bỏ qua",
    "Collapse" : "Thu gọn",
    "Import" : "Nhập vào",
    "Export" : "Xuất ra",
    "Help" : "Giúp đỡ",
    "Documentation" : "Tài liệu hướng dẫn",
    "Report a bug" : "Báo cáo lỗi"
},
"nplurals=1; plural=0;");

==> nextcloud-app-news-1%3A25.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/vi.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "Bài chưa đọc",
    "Download" : "Tải về",
    "Close" : "Đóng",
    "Web address" : "Địa chỉ Web",
    "No folder" : "Không có thư mục nào",
    "Folder name" : "Tên thư mục",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Feed exists already!" : "Nguồn đã tồn tại",
    "New folder" : "Tạo thư mục",
    "Folder exists already!" : "Thư mục đã tồn tại!",
    "Credentials" : "Giấy chứng nhận",
    "Subscribe" : "Theo dõi",
    "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
    "Move" : "Dịch chuyển",
    "Share" : "Chia sẻ",
    "Mark read" : "Đánh dấu là đã đọc",
    "All articles" : "Mọi bài viết",
    "Starred" : "Starred",
    "Settings" : "Cài đặt",
    "Documentation" : "Tài liệu hướng dẫn",
    "Keyboard shortcuts" : "Phím tắt",
    "Off" : "Tắt",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Rename Feed" : "Đổi tên nguồn dữ liệu",
    "Newest first" : "Mới trước",
    "Oldest first" : "Cũ trước",
    "Previous" : "Trước",
    "Next" : "Tiếp theo",
    "Mark unread" : "Đánh dấu là chưa đọc",
    "by" : "bởi",
    "from" : "từ",
    "Open website" : "Mở trang web",
    "Title" : "Tên",
    "Not available" : "Không khả dụng",
    "Keyboard shortcut" : "Phím tắt",
    "Action" : "Hành động",
    "right" : "phải",
    "left" : "trái",
    "Refresh" : "Làm mới",
    "Shift" : "Shift",
    "Description" : "Mô tả",
    "Folder" : "Thư mục",
    "Go back" : "Quay lại",
    "Create" : "Tạo",
    "Dismiss" : "Bỏ qua",
    "Collapse" : "Thu gọn",
    "Import" : "Nhập vào",
    "Export" : "Xuất ra",
    "Help" : "Giúp đỡ",
    "Report a bug" : "Báo cáo lỗi"
},
"nplurals=1; plural=0;");
